# CallAI

CallAI是一个简单易用的OpenAI API封装库，提供了更友好的接口和功能，使开发者能够更方便地使用大型语言模型。

## 安装

```bash
pip install callai
```

## 主要特性

- 兼容OpenAI官方API
- 简化的调用接口
- 支持会话管理
- 内置函数调用功能
- 支持流式响应

## 快速开始

### 基本用法

```python
from callai import AI

# 初始化客户端
ai = AI(api_key="your-api-key", default_model="gpt-3.5-turbo")

# 简单问答
response = ai.ask("请介绍一下Python语言的特点")
print(response)

# 使用系统提示
response = ai.ask("我应该如何入门Python?", system_prompt="你是一位编程教育专家")
print(response)

# 流式输出
for chunk in ai.stream_ask("讲一个关于AI的故事"):
    print(chunk, end="", flush=True)
```

### 会话管理

```python
# 创建会话
session = ai.session(system_prompt="你是一位AI助手")

# 在会话中交流
response = session.ask("你好，请问你是谁?")
print(response)

response = session.ask("我们刚才聊了什么?")
print(response)

# 保存会话
session.save_json("my_session.json")

# 加载会话
restored_session = ai.load_json("my_session.json")
```

### 函数调用

```python
from callai import AI, Tool

# 定义工具函数
@Tool.register
def get_weather(location: str, unit: str = "celsius"):
    """获取指定位置的天气信息
    
    Args:
        location: 位置名称，如"北京"
        unit: 温度单位，可选值为"celsius"或"fahrenheit"
    """
    # 模拟天气API返回
    return {"temperature": 25, "condition": "晴天", "location": location, "unit": unit}

# 使用工具函数
ai = AI(api_key="your-api-key")
result = ai.call_with_tools("北京今天的天气怎么样?")
print(result)
```

## API参考

详细的API文档请访问我们的[官方网站](https://github.com/aixiasang/callai)。

## 许可证

本项目采用MIT许可证。详见LICENSE文件。 